function getFSmodule() {

    if(typeof Blazor != "undefined" &&  typeof Blazor.runtime != "undefined" && typeof Blazor.runtime.Module != "undefined" && typeof Blazor.runtime.Module.FS != "undefined")
    {
        return Blazor.runtime.Module.FS;
    }
    if(typeof window.Module != "undefined" && typeof window.Module.FS != "undefined")
    {
        return window.Module.FS;
    }

    throw new Error('FS Module not found`');
}
export async function downloadStream(contentStreamReference, downloadName , contentType) {
    
    const [arrayBuffer] = await Promise.all([contentStreamReference.arrayBuffer()]);
    const blob = new Blob([arrayBuffer]);
    const url = URL.createObjectURL(blob);
    triggerFileDownload(url,downloadName,contentType);
    URL.revokeObjectURL(url);
    return true
}

export async function downloadFile(filePath, downloadName ,contentType) {

    const FSModule = getFSmodule();
    if (FSModule.analyzePath(filePath).exists) {

        const waitFlush = new Promise((done, _) => {
            setTimeout(done, 10);
        });

        await waitFlush;
        const data = await FSModule.readFile(filePath);
        const blob = new Blob([data])
        const url = URL.createObjectURL(blob);
        triggerFileDownload(url, downloadName,contentType);
        URL.revokeObjectURL(url);
        return true;
    }
    console.error(`Saving error ${filePath} not found`);
    return false;
    
}


function triggerFileDownload(url, fileName, contentType ) {
    const anchorElement = document.createElement('a');
    anchorElement.href = url;

    if (fileName) {
        anchorElement.download = fileName;
        anchorElement.contentType = contentType;
    }
    anchorElement.click();
    anchorElement.remove();
}